==> nextcloud-29.0.12.tar.bz2: nextcloud/apps/circles/l10n/hr.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Izbrisali ste {circle}",
    "{author} deleted {circle}" : "{author} je izbrisao {circle}",
    "You removed {member} from {circle}" : "Uklonili ste {member} iz {circle}",
    "You joined {circle}" : "Pridružili ste se {circle}",
    "{member} joined {circle}" : "{member} se pridružio {circle}",
    "You accepted the invitation to join {circle}" : "Prihvatili ste pozivnicu za pridruživanje {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} je prihvatio pozivnicu za pridruživanje {circle}",
    "You added {member} as member to {circle}" : "Dodali ste {member} kao člana u {circle}",
    "You have been added as member to {circle} by {author}" : "{author} vas je dodao kao člana u {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} je dodao {member} kao člana u {circle}",
    "You added {external} to {circle}" : "Dodali ste {external} u {circle}",
    "{external} has been added to {circle} by {author}" : "{author} je dodao {external} u {circle}",
    "You accepted {member}'s request to join {circle}" : "Prihvatili ste poziv {member} na sudjelovanje u {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Vaš zahtjev za pridruživanje {circle} prihvatio je {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} je prihvatio zahtjev {member} za pridruživanje {circle}",
    "You left {circle}" : "Napustili ste {circle}",
    "{member} left {circle}" : "{member} je napustio {circle}",
    "You declined the invitation to join {circle}" : "Odbili ste poziv za pridruživanje {circle}",
    "{member} declined an invitation to join {circle}" : "{član} je odbio poziv za pridruživanje {circle}",
    "You cancelled your request to join {circle}" : "Otkazali ste zahtjev za pridruživanje {circle}",
    "You have been removed from {circle} by {author}" : "{author} vas je uklonio iz {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} je uklonio {member} iz {circle}",
    "You removed {external} from {circle}" : "Uklonili ste {external} iz {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} je uklonio {external} iz {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Otkazali ste poziv {member} na sudjelovanje u {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} je otkazao vaš poziv za pridruživanje {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} je otkazao poziv {member} na sudjelovanje u {circle}",
    "You dismissed {member}'s request to join {circle}" : "Zanemarili ste poziv {member} na sudjelovanje u {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} je zanemario vaš zahtjev za pridruživanje {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} je zanemario zahtjev {member} za pridruživanje {circle}",
    "You invited {member} to join {circle}" : "Pozvali ste {member} da se pridruži {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vas je pozvao da se pridružite {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} je pozvao {member} da se pridruži {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Promijenili ste razinu {member} u {circle} na %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} je promijenio vašu razinu u {circle} na %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} je promijenio razinu {member} u {circle} na %1$s",
    "You sent a request to join {circle}" : "Poslali ste zahtjev za pridruživanje {circle}",
    "{member} sent a request to join {circle}" : "{member} je poslao zahtjev za pridruživanje {circle}",
    "You are the new owner of {circle}" : "Vi ste novi vlasnik {circle}",
    "{member} is the new owner of {circle}" : "{member} je novi vlasnik {circle}",
    "Shared to Circles" : "Dijeljeno u krugovima",
    "Single" : "Jedan",
    "Personal" : "Osobno",
    "System" : "Sustav",
    "Visible" : "Vidljivo",
    "Open" : "Otvori",
    "Invite" : "Poziv",
    "Friends" : "Prijatelji",
    "Password protected" : "Zaštićeno zaporkom",
    "No Owner" : "Nema vlasnika",
    "Hidden" : "Skriveno",
    "Backend" : "Pozadinski sustav",
    "Local" : "Lokalno",
    "Root" : "Korijen",
    "Federated" : "Udruženo",
    "Mount point" : "Točka postavljanja",
    "Nextcloud Group" : "Nextcloud grupa",
    "Email address" : "Adresa e-pošte",
    "Contact" : "Kontakt",
    "Circle" : "Krug",
    "Nextcloud App" : "Nextcloud aplikacija",
    "Member" : "Član",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Vlasnik",
    "%s shared »%s« with you." : "%s dijeli »%s« s vama.",
    "%s shared »%s« with \"%s\"." : "%s dijeli »%s« s „%s“.",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s dijeli »%2$s« s vama.\nTrebali ste već primiti poruku e-pošte s poveznicom za pristupanje.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s dijeli »%2$s« s vama. Trebali ste već primiti poruku e-pošte s poveznicom za pristupanje.",
    "Password to access »%1$s« shared to you by %2$s" : "Zaporku za pristupanje »%1$s« s vama dijeli %2$s",
    "Password to access »%s«" : "Zaporka za pristupanje »%s«",
    "It is protected with the following password:" : "Zaštićeno je sljedećom zaporkom:",
    "%1$s via %2$s" : "%1$s putem %2$s",
    "Click the button below to open it." : "Kliknite gumb u nastavku za otvaranje.",
    "Open »%s«" : "Otvori »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s dijeli više datoteka s vama.\nTrebali ste primiti poruku e-pošte s poveznicom za pristupanje datotekama.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s dijeli više datoteka s vama. Trebali ste primiti poruku e-pošte s poveznicom za pristupanje datotekama.",
    "Password to access files shared to you by %1$s" : "Zaporka za pristupanje datotekama koju s vama dijeli %1$s",
    "Password to access files" : "Zaporka za pristupanje datotekama",
    "%s shared multiple files with \"%s\"." : "%s dijeli više datoteka s „%s“.",
    "%s shared multiple files with you." : "%s dijeli više datoteka s vama.",
    "Boot up" : "Pokreni",
    "Fresh installation status" : "Status svježe instalacije",
    "Building Local Database" : "Izgradnja lokalne baze podataka",
    "Testing Basic Circle Creation" : "Ispitivanje stvaranja osnovnog kruga",
    "Adding local users and moderators" : "Dodavanje lokalnih korisnika i moderatora",
    "Files" : "Datoteke",
    "This feature is not available for personal circles" : "Ova značajka nije dostupna za osobne krugove",
    "This member is not a moderator" : "Ovaj član nije moderator",
    "Insufficient privileges" : "Nedovoljne ovlasti",
    "This member does not exist" : "Ovaj član ne postoji",
    "Level cannot be changed for this type of member" : "Razina se ne može promijeniti za ovu vrstu člana",
    "You are already a member of this circle" : "Već ste član ovog kruga",
    "You have been blocked from this circle" : "Blokirani ste iz ovog kruga",
    "Accept" : "Prihvati",
    "Refuse" : "Odbij",
    "%s" : "%s",
    "%s owned by %s" : "%s u vlasništvu %s",
    "%s shared a file with you." : "%s dijeli datoteku s vama.",
    "Bring cloud-users closer together." : "Približite korisnike oblaka.",
    "No files in here" : "Nema datoteka",
    "No entries found in this folder" : "U ovoj mapi nisu pronađeni nikakvi zapisi",
    "Name" : "Naziv",
    "Size" : "Veličina",
    "Modified" : "Promijenjeno",
    "You are now a member of the Circle \"%2$s\"" : "Postali ste član kruga „%2$s”",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s vas je pozvao u krug „%2$s”",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s je poslao zahtjev za učlanjenje u krug „%2$s”",
    "Leave the circle" : "Napusti krug"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-31.0.9.tar.bz2: nextcloud/apps/circles/l10n/hr.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Izbrisali ste {circle}",
    "{author} deleted {circle}" : "{author} je izbrisao {circle}",
    "You removed {member} from {circle}" : "Uklonili ste {member} iz {circle}",
    "You joined {circle}" : "Pridružili ste se {circle}",
    "{member} joined {circle}" : "{member} se pridružio {circle}",
    "You accepted the invitation to join {circle}" : "Prihvatili ste pozivnicu za pridruživanje {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} je prihvatio pozivnicu za pridruživanje {circle}",
    "You added {member} as member to {circle}" : "Dodali ste {member} kao člana u {circle}",
    "You have been added as member to {circle} by {author}" : "{author} vas je dodao kao člana u {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} je dodao {member} kao člana u {circle}",
    "You added {external} to {circle}" : "Dodali ste {external} u {circle}",
    "{external} has been added to {circle} by {author}" : "{author} je dodao {external} u {circle}",
    "You accepted {member}'s request to join {circle}" : "Prihvatili ste poziv {member} na sudjelovanje u {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Vaš zahtjev za pridruživanje {circle} prihvatio je {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} je prihvatio zahtjev {member} za pridruživanje {circle}",
    "You left {circle}" : "Napustili ste {circle}",
    "{member} left {circle}" : "{member} je napustio {circle}",
    "You declined the invitation to join {circle}" : "Odbili ste poziv za pridruživanje {circle}",
    "{member} declined an invitation to join {circle}" : "{član} je odbio poziv za pridruživanje {circle}",
    "You cancelled your request to join {circle}" : "Otkazali ste zahtjev za pridruživanje {circle}",
    "You have been removed from {circle} by {author}" : "{author} vas je uklonio iz {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} je uklonio {member} iz {circle}",
    "You removed {external} from {circle}" : "Uklonili ste {external} iz {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} je uklonio {external} iz {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Otkazali ste poziv {member} na sudjelovanje u {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} je otkazao vaš poziv za pridruživanje {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} je otkazao poziv {member} na sudjelovanje u {circle}",
    "You dismissed {member}'s request to join {circle}" : "Zanemarili ste poziv {member} na sudjelovanje u {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} je zanemario vaš zahtjev za pridruživanje {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} je zanemario zahtjev {member} za pridruživanje {circle}",
    "You invited {member} to join {circle}" : "Pozvali ste {member} da se pridruži {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vas je pozvao da se pridružite {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} je pozvao {member} da se pridruži {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Promijenili ste razinu {member} u {circle} na %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} je promijenio vašu razinu u {circle} na %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} je promijenio razinu {member} u {circle} na %1$s",
    "You sent a request to join {circle}" : "Poslali ste zahtjev za pridruživanje {circle}",
    "{member} sent a request to join {circle}" : "{member} je poslao zahtjev za pridruživanje {circle}",
    "You are the new owner of {circle}" : "Vi ste novi vlasnik {circle}",
    "{member} is the new owner of {circle}" : "{member} je novi vlasnik {circle}",
    "Single" : "Jedan",
    "Personal" : "Osobno",
    "System" : "Sustav",
    "Visible" : "Vidljivo",
    "Open" : "Otvori",
    "Invite" : "Poziv",
    "Friends" : "Prijatelji",
    "Password protected" : "Zaštićeno zaporkom",
    "No Owner" : "Nema vlasnika",
    "Hidden" : "Skriveno",
    "Backend" : "Pozadinski sustav",
    "Local" : "Lokalno",
    "Root" : "Korijen",
    "Federated" : "Udruženo",
    "Mount point" : "Točka postavljanja",
    "Nextcloud Group" : "Nextcloud grupa",
    "Email address" : "Adresa e-pošte",
    "Contact" : "Kontakt",
    "Nextcloud App" : "Nextcloud aplikacija",
    "Member" : "Član",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Vlasnik",
    "%s shared »%s« with you." : "%s dijeli »%s« s vama.",
    "%s shared »%s« with \"%s\"." : "%s dijeli »%s« s „%s“.",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s dijeli »%2$s« s vama.\nTrebali ste već primiti poruku e-pošte s poveznicom za pristupanje.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s dijeli »%2$s« s vama. Trebali ste već primiti poruku e-pošte s poveznicom za pristupanje.",
    "Password to access »%1$s« shared to you by %2$s" : "Zaporku za pristupanje »%1$s« s vama dijeli %2$s",
    "Password to access »%s«" : "Zaporka za pristupanje »%s«",
    "It is protected with the following password:" : "Zaštićeno je sljedećom zaporkom:",
    "%1$s via %2$s" : "%1$s putem %2$s",
    "Click the button below to open it." : "Kliknite gumb u nastavku za otvaranje.",
    "Open »%s«" : "Otvori »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s dijeli više datoteka s vama.\nTrebali ste primiti poruku e-pošte s poveznicom za pristupanje datotekama.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s dijeli više datoteka s vama. Trebali ste primiti poruku e-pošte s poveznicom za pristupanje datotekama.",
    "Password to access files shared to you by %1$s" : "Zaporka za pristupanje datotekama koju s vama dijeli %1$s",
    "Password to access files" : "Zaporka za pristupanje datotekama",
    "%s shared multiple files with \"%s\"." : "%s dijeli više datoteka s „%s“.",
    "%s shared multiple files with you." : "%s dijeli više datoteka s vama.",
    "Boot up" : "Pokreni",
    "Fresh installation status" : "Status svježe instalacije",
    "Building Local Database" : "Izgradnja lokalne baze podataka",
    "Testing Basic Circle Creation" : "Ispitivanje stvaranja osnovnog kruga",
    "Adding local users and moderators" : "Dodavanje lokalnih korisnika i moderatora",
    "Files" : "Datoteke",
    "This feature is not available for personal circles" : "Ova značajka nije dostupna za osobne krugove",
    "This member is not a moderator" : "Ovaj član nije moderator",
    "Insufficient privileges" : "Nedovoljne ovlasti",
    "This member does not exist" : "Ovaj član ne postoji",
    "Level cannot be changed for this type of member" : "Razina se ne može promijeniti za ovu vrstu člana",
    "You are already a member of this circle" : "Već ste član ovog kruga",
    "You have been blocked from this circle" : "Blokirani ste iz ovog kruga",
    "Accept" : "Prihvati",
    "Refuse" : "Odbij",
    "%s" : "%s",
    "%s owned by %s" : "%s u vlasništvu %s",
    "%s shared a file with you." : "%s dijeli datoteku s vama.",
    "Open %s" : "Otvori %s",
    "Bring cloud-users closer together." : "Približite korisnike oblaka.",
    "Loading…" : "Učitavanje…",
    "No files in here" : "Nema datoteka",
    "No entries found in this folder" : "U ovoj mapi nisu pronađeni nikakvi zapisi",
    "Name" : "Naziv",
    "Size" : "Veličina",
    "Modified" : "Promijenjeno",
    "Shared to Circles" : "Dijeljeno u krugovima",
    "Circle" : "Krug"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
